##  Step 2: Define the Source System
Select which system serves as the source of truth for this relation:
Source System Options Source System | Description | When to Use
---|---|---
SAP LeanIX | Relation data flows from SAP LeanIX to Jira Service Management | Use when relations are managed in SAP LeanIX
Jira Service Management | Relation data flows from Jira Service Management to SAP LeanIX | Use when relations are managed in Jira Service Management


Choose Next after selecting the source system.
